# This script supports the Raspberry Pi Pico board and the Lilygo ESP32-S2 board
# Color OLED Display: http://educ8s.tv/part/ColorOLED
# Raspberry Pi Pico: http://educ8s.tv/part/RaspberryPiPico
# ESP32-S2 Board: http://educ8s.tv/part/esp32s2

import board, busio, displayio, os, time
import terminalio #Just a font
from adafruit_ssd1331 import SSD1331
from adafruit_display_text import label
from adafruit_display_shapes.rect import Rect
from adafruit_display_shapes.circle import Circle
from adafruit_display_shapes.line import Line
from adafruit_display_shapes.triangle import Triangle
from adafruit_display_text import label

SCREEN_WIDTH = 96
SCREEN_HEIGHT = 64

FPS = 120
FPS_DELAY = 1 / FPS

displayio.release_displays()

board_type = os.uname().machine
print(f"Board: {board_type}")

if 'Pico' in board_type:
    clk_pin, mosi_pin, reset_pin, dc_pin, cs_pin = board.GP18, board.GP19, board.GP16, board.GP20, board.GP17
elif 'ESP32-S2' in board_type:
    mosi_pin, clk_pin, reset_pin, cs_pin, dc_pin = board.IO35, board.IO36, board.IO38, board.IO34, board.IO37    
else:
    mosi_pin, clk_pin, reset_pin, cs_pin, dc_pin = board.GP11, board.GP10, board.GP17, board.GP18, board.GP16
    print("This board is not supported. Change the pin definitions above.")

spi = busio.SPI(clock=clk_pin, MOSI=mosi_pin)

display_bus = displayio.FourWire(spi, command=dc_pin, chip_select=cs_pin, reset=reset_pin)

display = SSD1331(display_bus, width=SCREEN_WIDTH, height=SCREEN_HEIGHT)

# Make the display context
splash = displayio.Group()
display.root_group=splash
x0=20
y0=17
r0=10
text = "* Hello World *"
text_area = label.Label(terminalio.FONT, text=text, color=0xFFFF00, x=0, y=10)
rect = Rect(x0, y0, 20, 20, fill=None,outline=0x00FF00)
circle = Circle(x0+r0, y0+r0+25, r0,fill=None ,outline=0xFF00FF)
triangle = Triangle(x0+30, y0+20, x0+40, y0, x0+50, y0+20, fill=None, outline=0xFF0000)
line1=Line(x0+30,y0+25,x0+50,y0+45,0x0000FF)
line2=Line(x0+30,y0+45,x0+50,y0+25,0x0000FF)

splash.append(text_area)
time.sleep(1)
splash.append(rect)
time.sleep(1)
splash.append(circle)
time.sleep(1)
splash.append(triangle)
time.sleep(1)
splash.append(line1)
time.sleep(1)
splash.append(line2)
time.sleep(1)