# This script supports the Raspberry Pi Pico board and the Lilygo ESP32-S2 board
# Color OLED Display: http://educ8s.tv/part/ColorOLED
# Raspberry Pi Pico: http://educ8s.tv/part/RaspberryPiPico
# ESP32-S2 Board: http://educ8s.tv/part/esp32s2

import board, busio, displayio, os, time
from adafruit_st7789 import ST7789
from adafruit_display_shapes.rect import Rect
from adafruit_display_shapes.circle import Circle
from adafruit_display_shapes.line import Line
from adafruit_display_shapes.triangle import Triangle

SCREEN_WIDTH = 240
SCREEN_HEIGHT = 320
FPS = 120
FPS_DELAY = 1 / FPS
displayio.release_displays()
board_type = os.uname().machine

clk_pin, mosi_pin, reset_pin, dc_pin, cs_pin = board.GP2, board.GP3, board.GP6, board.GP7, board.GP5

spi = busio.SPI(clock=clk_pin, MOSI=mosi_pin)  # SPI0BUS PIN
display_bus = displayio.FourWire(
    spi, command=dc_pin, chip_select=cs_pin, reset=reset_pin) # other PIN
display = ST7789(display_bus, width=SCREEN_WIDTH, height=SCREEN_HEIGHT)

# Make the display context
splash = displayio.Group()
display.root_group=splash

# Make a background color fill
color_bitmap = displayio.Bitmap(SCREEN_WIDTH, SCREEN_HEIGHT, 1)
color_palette = displayio.Palette(1)
color_palette[0] = 0x002000
bg_sprite = displayio.TileGrid(color_bitmap, x=0, y=0, pixel_shader=color_palette)
splash.append(bg_sprite)

class Ball:
    def __init__(self, size, x, y):
        self.size = size
        self.x = x
        self.y = y
        self.speed_x = 1
        self.speed_y = 1
        
        # Create a circle object for the ball
        self.circle = Circle(self.x, self.y, self.size, fill=0x0000FF)
        self.SCREEN_HEIGHT = 320
        self.SCREEN_WIDTH = 240
    
    def update(self, left_paddle, right_paddle):
        
         if self.x <= left_paddle.x - self.size:
            self.speed_x *= -1

         if self.x + self.size + right_paddle.width == right_paddle.x:
            self.speed_x *= -1
        
         if self.x >= self.SCREEN_WIDTH-self.size*2 or self.x <= self.size:
            self.speed_x *= -1
            
         if self.y >= self.SCREEN_HEIGHT-self.size*2 or self.y <= self.size:
            self.speed_y *= -1
            
         self.x += self.speed_x
         self.y += self.speed_y
        
         self.circle.x = self.x
         self.circle.y = self.y

class Paddle:
    def __init__(self, width, height, x, y, color):
        self.height = height
        self.width = width
        self.x = x
        self.y = y
        self.rect = Rect(self.x, self.y, self.width, self.height, fill = color)
        self.SCREEN_HEIGHT = 320
    
    def update(self, ball):
        
        if self.y > self.SCREEN_HEIGHT - self.height:
            self.y = self.SCREEN_HEIGHT - self.height
        
        if self.y < 0:
            self.y = 0

        if self.y < ball.y:
            self.y += 1
        if self.y > ball.y:
            self.y -= 1
            
        self.rect.x = self.x
        self.rect.y = self.y

right_paddle = Paddle(5,40,SCREEN_WIDTH-5,int(SCREEN_HEIGHT/2 - 10), 0xFF0000)
splash.append(right_paddle.rect)

left_paddle = Paddle(5,40,0,int(SCREEN_HEIGHT/2 - 10), 0xFFFF00)
splash.append(left_paddle.rect)

ball = Ball(5,10,10)
splash.append(ball.circle)

last_update_time = 0
now = 0
loops_since_update = 0

while True:
    # update time variable
    now = time.monotonic()

    # check if the delay time has passed since the last game update
    if last_update_time + FPS_DELAY <= now:
        
        # update objects
        ball.update(left_paddle, right_paddle )
        left_paddle.update(ball)
        right_paddle.update(ball)
        
        last_update_time = now
        loops_since_update = 0
    else:
        loops_since_update += 1